@@ -75,7 +75,8 @@ ggdotplot <- function(data, x, y,
   y <- .dd$y
 
 
-  data[, x] <- factor(data[, x])
+  if(!is.null(order)) data[, x] <- factor(data[, x], levels = order)
+  else if(!is.factor(data[, x])) data[, x] <- as.factor(data[, x])
 
   p <- ggplot(data, aes_string(x, y))
   if("none" %in% add) add <- "none"
